@@ -163,13 +163,45 @@ def test_url_to_file_404(url_404):
     )
 
 
+@pytest.mark.parametrize(
+    "url",
+    [rss_url],
+)
+def test_from_url(url):
+    """Test `from_url` with real feed URLs. (Warning: `sleep` used for politeness)."""
+    sleep(3)
+    fm_via_string = FeedModifier.from_url(url)
+    fm_via_file = FeedModifier.from_url(url, path=tmp_dir / "blog-feed.xml")
+    assert _same_attributes(fm_via_string, fm_via_file)
+
+
+def test_from_string(simple_fnames):
+    """Test initialization from string rather than url or filepath."""
+    for fname in simple_fnames:
+        with open(data_dir / fname, "rb") as f:
+            contents = f.read()
+            # print(type(contents))
+            fm = FeedModifier.from_string(contents)
+
+            # Write to file, load from file, and compare
+            out_path = tmp_dir / fname
+            fm.write(out_path)
+            deserialized = FeedModifier.from_file(out_path)
+            assert _same_attributes(fm, deserialized)
+
+            # Output as string, load from string, and compare
+            out_string = fm.write(out_path)
+            deserialized = FeedModifier.from_string(out_string)
+            assert _same_attributes(fm, deserialized)
+
+
 def test_write(simple_fnames, simple_fms):
     """Test writing the modified feed (and associated FeedModifier data) to XML."""
     for fname, fm in zip(simple_fnames, simple_fms):
         out_path = tmp_dir / fname
         fm.write(out_path)
         # TODO: actually write these tests, expected output files, etc.
-        deserialized = fm.from_file(out_path)
+        deserialized = FeedModifier.from_file(out_path)
         assert _same_attributes(fm, deserialized)
         pass
 
